@@ -184,12 +184,12 @@ int EditorHighlighter::highlightParagraph ( const TQString & text, int )
       case Token::Identifier:
         {
           color = editor->highlightColor( Editor::Variable );
-#ifndef QT_NO_STL
+#ifndef TQT_NO_STL
 	  if( binary_search( fnames.constBegin(), fnames.constEnd(), text) ) {
-#else // QT_NO_STL
+#else // TQT_NO_STL
 	  #warning "Not using STL libraries; performance may be degraded..."
 	  if( fnames.find( text) != fnames.end()) {
-#endif // QT_NO_STL
+#endif // TQT_NO_STL
 	    color = editor->highlightColor( Editor::FunctionName );
 	  }
         }
